# ProSoul Quality Models Repository

In this folder there are several samples of quality models that can be used with 
ProSoul (just import them using the web editor). Here goes a description of them.

* alambic_quality_model.json: Quality Model used by default in Alambic project 
* basic_maturiy_model.json: Basic Maturiy Model defined in Bitergia (to be evolved)
* developer_model.json: Minimal Developer Model used in testing and with the focus 
in the developer point of view
* developer_model_grimoirelab_eclipse.json: the Developer Model with the thresholds adjusted to Eclipse Foundation
* developer_model_grimoirelab_linuxfoundation2018.json: the Developer Model with the thresholds adjusted to Linux Foundation
* developer_model_grimoirelab_mozilla.json: the Developer Model with the thresholds adjusted to Mozilla Foundation
* developer_model_size.json: the Developer Model including the size of the product and the community  
* developer_model_size_grimoirelab_chaoss.json: Developer Model with size with the thresholds adjusted to CHAOSS
* grimoirelab_ossmeter_qm.json: the OSSMeter Quality Model in GrimoireLab format
* grimoirelab_qm.json: a sample Quality Model focused in Community
* ossmeter_qm.json: the OSSMeter Quality Model
* polarsys_qm.json: the Polarsys Quality Model
* qmodel_QualOSS.json: the QualOSS Quality Model
